SameOperandsAndResultType

Trait SameOperandsAndResultType 

pub trait SameOperandsAndResultType:
    Op
    + SameOperandsType
    + SameResultsType {
    // Provided method
    fn get_type(&self, ctx: &Context) -> Ptr<TypeObj> { ... }
}
An Op with at least one result and one operand, and them all having the same type. See MLIR’s SameOperandsAndResultType.

Provided Methods

fn get_type(&self, ctx: &Context) -> Ptr<TypeObj>

Get the common type of results / operands.