pub trait SameOperandsAndResultType:
Op
+ SameOperandsType
+ SameResultsType {
// Provided method
fn get_type(&self, ctx: &Context) -> Ptr<TypeObj> { ... }
}Expand description
An Op with at least one result and one operand, and them all having the same type. See MLIR’s SameOperandsAndResultType.